pub struct DraftBotEvent { /* private fields */ }Expand description
Bot draft pick events.
Parsed from DraftStatus: "PickNext" and BotDraft_DraftPick entries.
Each pick is independently valuable and must survive crashes.
Implementations
Sourceimpl DraftBotEvent
impl DraftBotEvent
Sourcepub fn new(metadata: EventMetadata, payload: Value) -> Self
pub fn new(metadata: EventMetadata, payload: Value) -> Self
Constructs a new event with the given metadata and payload.
Sourcepub fn metadata(&self) -> &EventMetadata
pub fn metadata(&self) -> &EventMetadata
Returns the shared event metadata.