pub struct SessionEvent { /* private fields */ }Expand description
Session identity and connection events.
Covers authenticateResponse and FrontDoorConnection.Close.
Needed to tag all subsequent events with player identity.
Implementations
Sourceimpl SessionEvent
impl SessionEvent
Sourcepub fn new(metadata: EventMetadata, payload: Value) -> Self
pub fn new(metadata: EventMetadata, payload: Value) -> Self
Constructs a new event with the given metadata and payload.
Sourcepub fn metadata(&self) -> &EventMetadata
pub fn metadata(&self) -> &EventMetadata
Returns the shared event metadata.