try_parse

Function try_parse 

pub fn try_parse(
    entry: &LogEntry,
    timestamp: Option<DateTime<Utc>>,
) -> Option<GameEvent>
Attempts to parse a LogEntry as a connection-error event.

Dispatches on entry.header:

The timestamp is None when the log entry header did not contain a parseable timestamp. It is passed through to EventMetadata so downstream consumers can distinguish real vs missing timestamps.